@@ -1,5 +1,3 @@
-# coding=utf-8
-
 from typing import Union, List
 
 from sqlalchemy.orm import Query
@@ -23,9 +21,9 @@ class BaseModelMixin:
             self,
             ignore: Union[str, List] = None,
             only: Union[str, List] = None,
-            max_depth: int = None,
+            include: Union[str, List] = None,
     ):
-        return model_to_dict(self, ignore=ignore, only=only, max_depth=max_depth)
+        return model_to_dict(self, ignore=ignore, only=only, include=include)
 
     def update_by_dict(
             self,
