@@ -1,5 +1,3 @@
-# coding=utf-8
-
 from .bind_annotation import blueprint
 from .bind_annotation import delete_route
 from .bind_annotation import get_route
@@ -15,12 +13,12 @@ from .filter_annotation import app_before_request
 from .filter_annotation import app_error_handler
 from .filter_annotation import before_request
 from .filter_annotation import error_handler
-from .param_annotation import CookieValue
-from .param_annotation import FilePart
-from .param_annotation import FormValue
-from .param_annotation import PathVariable
-from .param_annotation import RequestBody
-from .param_annotation import RequestHeader
-from .param_annotation import RequestParam
+from .request_annotation import CookieValue
+from .request_annotation import FilePart
+from .request_annotation import FormValue
+from .request_annotation import PathVariable
+from .request_annotation import RequestBody
+from .request_annotation import RequestHeader
+from .request_annotation import RequestParam
 from .request_filter import RequestFilter
 from .request_filter import RequestFilterChain
