@@ -1,6 +1,4 @@
-# coding=utf-8
-
-from guniflask.config.app_config import Settings
+from guniflask.config import Settings
 
 
 def test_get():
